#include "serversettings.h"
#include <QFormLayout>
#include <QSqlDatabase>
#include <QFileDialog>

ServerSettings::ServerSettings(QWidget *parent) :
        AbstractSettings(parent)
{
    QFormLayout * fLayout = new QFormLayout;
    QVBoxLayout * layout = new QVBoxLayout;
    QHBoxLayout * hLayout = new QHBoxLayout;


    mHostEdit = new QLineEdit;
    mDatabaseNameEdit= new QLineEdit;
    mComboBox = new QComboBox;
    mLogoLabel = new QLabel;
    mBrowseSqliteBtn = new QToolButton;

    mLogoLabel->setStyleSheet("background-color: rgb(255, 255, 255);");
    mLogoLabel->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Fixed);



    hLayout->addWidget(mDatabaseNameEdit);
    hLayout->addWidget(mBrowseSqliteBtn);

    fLayout->addRow("server driver",mComboBox);
    fLayout->addRow("host",mHostEdit);
    fLayout->addRow("database name",hLayout);

    layout->addWidget(mLogoLabel);
    layout->addLayout(fLayout);
    setLayout(layout);

    setWindowTitle("server");


    //load server type
    foreach ( QString driver, QSqlDatabase::drivers() )
    {

        QString logo;
        if ( driver.contains("MYSQL"))
            logo =":/logo/mysql.png";

        if ( driver.contains("SQLITE"))
            logo =":/logo/sqlite.png";

        if ( driver.contains("POSTGRESQL"))
            logo =":/logo/postresql.png";

        if ( driver.contains("ORACLE"))
            logo =":/logo/oracle.png";


        mComboBox->addItem(QIcon(logo),driver, logo);
    }

    driverChanged();
    connect(mComboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(driverChanged()));
    connect(mBrowseSqliteBtn,SIGNAL(clicked()),this,SLOT(loadSqliteFile()));


}
void ServerSettings::save()
{
    QSettings settings;
    settings.beginGroup("server");

    settings.setValue("driver", mComboBox->currentText());
    settings.setValue("host", mHostEdit->text());
    settings.setValue("databaseName", mDatabaseNameEdit->text());
    settings.endGroup();

}

void ServerSettings::load()
{
    QSettings settings;
    settings.beginGroup("server");

    int id=mComboBox->findText(settings.value("driver").toString());
   mComboBox->setCurrentIndex(id);
    mHostEdit->setText(settings.value("host").toString());
    mDatabaseNameEdit->setText(settings.value("databaseName").toString());
    settings.endGroup();
    driverChanged();
}
void ServerSettings::driverChanged()
{

    //change logo
    QString logo = mComboBox->itemData(mComboBox->currentIndex(),Qt::UserRole).toString();
    QPixmap pix(logo);
    mLogoLabel->setPixmap(pix);
    QString drivers = mComboBox->itemText(mComboBox->currentIndex());

    if ( drivers.contains("SQLITE"))
    {
        mBrowseSqliteBtn->setHidden(false);
        mHostEdit->setEnabled(false);
    }
    else
    {
        mBrowseSqliteBtn->setHidden(true);
        mHostEdit->setEnabled(true);
    }


}
void ServerSettings::loadSqliteFile()
{


   QString fileName = QFileDialog::getOpenFileName(this,
         tr("Open Sqlite file"), "", tr("Sqlite Files (*.sqlite)"));


mDatabaseNameEdit->setText(fileName);



}
